@@ -43,7 +43,9 @@ gridlinesWrap = function(crs,
 		ellipseSmall@polygons[[1]]@Polygons[[1]]@coords = 
 			0.99*ellipseSmall@polygons[[1]]@Polygons[[1]]@coords 
 			
-		glinesT = rgeos::gIntersection(glinesT, ellipseSmall, byid=TRUE)
+		glinesT = rgeos::gIntersection(
+		  spTransform(glinesT,projection(ellipseSmall)), 
+		  ellipseSmall, byid=TRUE)
 	}
 	glinesData=data.frame(
 			direction = substr(names(glinesT), 1,1),
@@ -68,9 +70,12 @@ gridlinesWrap = function(crs,
 	fun1 = function(onedir) {		
 		lapply(
 				onedir@Lines, 
-				function(oneline) oneline@coords[
+				function(oneline) {
+				  result = oneline@coords[
 							which.max(abs(oneline@coords[,pointPos]))
 							,]
+				  result
+				}
 		)
 	}
 	
@@ -79,7 +84,13 @@ gridlinesWrap = function(crs,
 				t(simplify2array(fun1(qq2)))
 			}
 	)
-	
+
+	# at most three labels per line
+	manyPoints = which(unlist(lapply(legendPoints, nrow)) > 3)
+	for(D in manyPoints) {
+	  legendPoints[[D]] = legendPoints[[D]][c(1, nrow(legendPoints[[D]])), ]
+	}
+		
 	legendDf = glinesT@data[rep(1:length(glinesT),
 					unlist(lapply(legendPoints, nrow))
 			),]
