@@ -178,7 +178,8 @@ if(!haveRgdal) {
 if(haveRgdal){
   
   waterhouseWrap = spTransform(
-    waterhouseMerc, moll(waterhouseMerc)
+    waterhouseMerc, CRS("+proj=moll +lon_wrap=178.7729285 +lon_0=178.7729285 +x_0=0 +y_0=0 +ellps=WGS84 +units=m +no_defs ")
+    #moll(waterhouseMerc)
   )
   
   
